@@ -26,4 +26,5 @@ void gok_page_wordcomplete_refresh (void);
 gboolean gok_page_wordcomplete_apply (void);
 gboolean gok_page_wordcomplete_revert (void);
 void gok_page_wordcomplete_backup (void);
-
+void gok_page_wordcomplete_update_auxwordlist_from_control ();
+void gok_page_wordcomplete_toggle_wordlist (gboolean on);
